# srai-core


## Changleog

### 0.15.8
- added orderby to object store

### 0.15.8
- added orderby

### 0.15.7
- updated object store
- added limit and offset to query calls

### 0.15.6
- change load_document_for_query  to load_document_dict_for_query
- added load_document_for_query that returns a single document

### 0.15.5
- enabled mongo querries

### 0.15.4
- added port mapping

### 0.15.3
- fixed deploy issui

### 0.15.2
- added databases3

### 0.15.1
- typos in object store
- autocreate bucket in bytestore s3

### 0.15.0
- added object store
- added various ml types

### 0.14.4
- added srai_killall

### 0.14.3
- cleaned up much of the CI scripting

### 0.14.2
- added get_posix_timestamp()
- added SourceStore
- added pydantic dependancy

### 0.14.1
- changes to srai-release

### 0.14.0
- migrating to pyproject.toml

### 0.13.1
- added try load options to stores

### 0.13.0
- added dirstore options

### 0.12.0
- added in memory database
- added default release option